@@ -16,22 +16,21 @@ def getCoordKey(header, coord_type=default_coord, delimiter=default_delimiter):
     Return the coordinate identifier for a sequence description
 
     Arguments:
-      header : Sequence header string
-      coord_type : Sequence header format;
-                   one of ['illumina', 'solexa', 'sra', '454', 'presto'];
-                   if unrecognized type or None return sequence ID.
-      delimiter : Tuple of delimiters for (fields, values, value lists)
+      header (str): Sequence header string
+      coord_type (str): Sequence header format;
+                   one of 'illumina', 'solexa', 'sra', 'ena', '454', or 'presto';
+                   if unrecognized type or None, then return the input header.
+      delimiter (tuple): Tuple of delimiters for (fields, values, value lists)
 
     Returns:
-      str : Coordinate identifier as a string
+      str: Coordinate identifier as a string.
     """
-    #header = seq.id
     if coord_type in ('illumina', 'solexa'):
-        return header.split()[0].split('#')[0]
+        return header.split()[0].split('/')[0].split('#')[0]
+    elif coord_type in ('sra', 'ena'):
+        return '.'.join(header.split()[0].split('.')[:2])
     elif coord_type == '454':
         return header.split()[0]
-    elif coord_type == 'sra':
-        return '.'.join(header.split()[0].split('.')[:2])
     elif coord_type == 'presto':
         return parseAnnotation(header, delimiter=delimiter)['ID']
     else:
@@ -409,6 +408,7 @@ def convertIlluminaHeader(desc):
 
         @<instrument>:<flowcell lane>:<tile>:<x-pos>:<y-pos>#<index sequence>/<read number>
         @HWI-EAS209_0006_FC706VJ:5:58:5894:21141#ATCACG/1
+        @MS6_33112:1:1101:18371:1066/1
     """
     # Split description and assign field names
     try:
@@ -418,16 +418,20 @@ def convertIlluminaHeader(desc):
             x = fields[1].split(':')
             index = x[3]
             read_num = x[0]
-        else:
+        elif '#' in desc:
             fields = desc.split('#')
             x = fields[1].split('/')
             index = x[0]
             read_num = x[1]
+        else:
+            fields = desc.split('/')
+            index = None
+            read_num = fields[1]
 
         # Build header dictionary
         header = OrderedDict()
         header['ID'] = fields[0]
-        header['INDEX'] = index
+        if index is not None:  header['INDEX'] = index
         header['READ'] = read_num
     except:
         header = None
