@@ -626,8 +626,9 @@ def qualityConsensus(seq_list, min_qual=default_consensus_min_qual, min_freq=def
                          for c in qual_set}
 
         # Select character with highest consensus quality
-        cons = [(c, min(q, 90)) for c, q in qual_cons.items() \
-                if q == max(qual_cons.values())][0]
+        cons = sorted([(c, min(q, 90)) for c, q in qual_cons.items() \
+                if q == max(qual_cons.values())])[0]
+        
         # Assign N if consensus quality or frequency threshold is failed
         if cons[1] < min_qual or char_freq[cons[0]] < min_freq:
             cons = ('N', 0)
@@ -682,8 +683,9 @@ def frequencyConsensus(seq_list, min_freq=default_consensus_min_freq,
         freq_max = max(char_freq.values())
 
         # Assign consensus as most frequent character
-        cons = [c if char_freq[c] >= min_freq else 'N' \
-                for c in char_set if char_freq[c] == freq_max][0]
+        cons = sorted([c if char_freq[c] >= min_freq else 'N' \
+                for c in char_set if char_freq[c] == freq_max])[0]
+        
         consensus_seq.append(cons)
 
     # Define return SeqRecord
@@ -1020,7 +1022,7 @@ def extractAlignment(seq_record, start, length, rev_primer=False):
     return align
 
 
-def maskSeq(align, mode='mask', barcode=False, barcode_field=default_barcode_field,
+def maskSeq(align, mode='mask', barcode=False, barcode_length=None, barcode_field=default_barcode_field,
             primer_field=default_primer_field, delimiter=default_delimiter):
     """
     Create an output sequence with primers masked or cut
@@ -1029,6 +1031,7 @@ def maskSeq(align, mode='mask', barcode=False, barcode_field=default_barcode_fie
       align : a PrimerAlignment object.
       mode : defines the action taken; one of 'cut', 'mask', 'tag' or 'trim'.
       barcode : if True add sequence preceding primer to description.
+      barcode_length: length of barcode to extract. If None (default), use the whole sequence preceding the primer.
       barcode_field : name of the output barcode annotation.
       primer_field : name of the output primer annotation.
       delimiter : a tuple of delimiters for (annotations, field/values, value lists).
@@ -1041,7 +1044,7 @@ def maskSeq(align, mode='mask', barcode=False, barcode_field=default_barcode_fie
     # Build output sequence
     if mode == 'tag' or not align.align_primer:
         # Do not modify sequence
-        out_seq = seq
+        out_seq = seq[:]
     elif mode == 'trim':
         # Remove region before primer
         if not align.rev_primer:
@@ -1084,8 +1087,14 @@ def maskSeq(align, mode='mask', barcode=False, barcode_field=default_barcode_fie
 
     # Add ID sequence to description
     if barcode:
-        seq_code = seq[:align.start].seq if not align.rev_primer \
-            else seq[align.end:].seq
+        if barcode_length is None:
+            # Extract all sequence preceding the primer
+            seq_code = seq[:align.start].seq if not align.rev_primer \
+                else seq[align.end:].seq
+        else:
+            # Extract sequence preceding the primer up to barcode_length
+            seq_code = seq[(align.start - barcode_length):align.start].seq if not align.rev_primer \
+                else seq[align.end:(align.end + barcode_length)].seq
         out_seq.annotations['barcode'] = seq_code
         out_ann[barcode_field] = seq_code
 
